% This routine plots the germination rate as a function of temperature and
% light.  Light is converted to an equivalent depth using a typical
% insolation and a typical attenuation constant.
%
% Charlie Stock
% cstock@alum.mit.edu
%

clear all
clf

% Plot temperature versus depth
t = [0:0.05:20];
d = [0:-0.5:-100]

[TT,DD] = meshgrid(t,d);

% calculate light rates and dark rates
LR = 1.50+(8.72-1.50)*0.5*(tanh(0.790*TT-6.27)+1);
DR = 1.04+(4.26-1.04)*0.5*(tanh(0.394*TT-3.33)+1);

% calculate the light/dark thresholds, light is 2.4 Watts/m2 (~10
% micro-einsteins per m2 s-1), dark threshold is 1% of that.
lthresh = log(2.4/345.5)/0.2; 
dthresh = log(0.024/345.5)/0.2;

% start by assigning a light rate to all of the points
R = LR;
% assign a dark rate to those points below the dark threshold
bb = find(DD < dthresh);
R(bb) = DR(bb);
% interpolate between light and dark for other points
cc = find((DD < lthresh) & (DD > dthresh));
R(cc) = DR(cc) + (LR(cc)-DR(cc)) .* ...
        ((345.5*exp(0.2*DD(cc))-0.024)/(2.4-0.024));

% plot it up
axes('position',[0.2 0.2 0.6 0.6]);
[cs,h] = contour(TT,DD,R,[1:0.5:9],'k-');
clabel(cs,h,'manual')
aa = xlabel('Temperature (C)');
bb = ylabel('Depth (m)');
set(aa,'FontSize',12);
set(bb,'FontSize',12);
set(gca,'FontSize',12);
set(gca,'Ytick',[-100 -80 -60 -40 -20]);
 hold on
data = [2 4 6 8 15 2 4 6 8 15; -25 -25 -25 -25 -25 -48 -48 ...
-48 -48 -48]';
c = plot(data(:,1),data(:,2),'k.');
set(c, 'MarkerSize',15);
